![PyPI - Version](https://img.shields.io/pypi/v/freezy)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/freezy)
![GitHub License](https://img.shields.io/github/license/minsmis/freezy)

# freezy

- Calculate mouse speed using DLC coordinates.
- Automatic trace smoothing through '[savitzky golay](https://en.wikipedia.org/wiki/Savitzky%E2%80%93Golay_filter)'
  filter.

# How to use

```
pip install freezy
```

# Examples

- Refer 'examples' directory.

![Result: Route and speed](./examples/result_route_and_speed.png)
![Result: Speed and freezing](./examples/result_speed_and_freezing.png)
